==> haskell-profunctors-5.2-23-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-profunctors.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: profunctors
version: 5.2
id: profunctors-5.2-IlcvFEs1wh7HqcAN610i7Y
key: profunctors-5.2-IlcvFEs1wh7HqcAN610i7Y
license: BSD3
copyright: Copyright (C) 2011-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/profunctors/
synopsis: Profunctors
description:
    Profunctors
category: Control, Categories
author: Edward A. Kmett
exposed: True
exposed-modules:
    Data.Profunctor Data.Profunctor.Adjunction Data.Profunctor.Cayley
    Data.Profunctor.Choice Data.Profunctor.Closed
    Data.Profunctor.Composition Data.Profunctor.Mapping
    Data.Profunctor.Monad Data.Profunctor.Ran Data.Profunctor.Rep
    Data.Profunctor.Sieve Data.Profunctor.Strong
    Data.Profunctor.Traversing Data.Profunctor.Types
    Data.Profunctor.Unsafe
abi: a3efbfec018e46ecdb36abb912a0cc5a
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/profunctors-5.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/profunctors-5.2
data-dir: /usr/share/arm-linux-ghc-8.0.1/profunctors-5.2
hs-libraries: HSprofunctors-5.2-IlcvFEs1wh7HqcAN610i7Y
depends:
    base-4.9.0.0 base-orphans-0.5.4-5IQvrjd7gNP548VkOOyIq6
    bifunctors-5.4.1-DfVkdtHpKE8vmoB9WwpVO
    comonad-5-BAeQEuNFZnn4rrNJniQw1k
    contravariant-1.4-3AJtodz0hXH8pIpn4tqcA
    distributive-0.5.2-SlRGCHnocy81GrFzDcKVs
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-profunctors/html/profunctors.haddock
haddock-html: /usr/share/doc/haskell-profunctors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-profunctors-5.2-24-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-profunctors.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: profunctors
version: 5.2
id: profunctors-5.2-1HLm9WoKgF5GvKRjOhOJmS
key: profunctors-5.2-1HLm9WoKgF5GvKRjOhOJmS
license: BSD3
copyright: Copyright (C) 2011-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: experimental
homepage: http://github.com/ekmett/profunctors/
synopsis: Profunctors
description:
    Profunctors
category: Control, Categories
author: Edward A. Kmett
exposed: True
exposed-modules:
    Data.Profunctor Data.Profunctor.Adjunction Data.Profunctor.Cayley
    Data.Profunctor.Choice Data.Profunctor.Closed
    Data.Profunctor.Composition Data.Profunctor.Mapping
    Data.Profunctor.Monad Data.Profunctor.Ran Data.Profunctor.Rep
    Data.Profunctor.Sieve Data.Profunctor.Strong
    Data.Profunctor.Traversing Data.Profunctor.Types
    Data.Profunctor.Unsafe
abi: c68083290bdd0375181cbdd2ab5a99c4
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/profunctors-5.2
library-dirs: /usr/lib/ghc-8.0.1/site-local/profunctors-5.2
data-dir: /usr/share/arm-linux-ghc-8.0.1/profunctors-5.2
hs-libraries: HSprofunctors-5.2-1HLm9WoKgF5GvKRjOhOJmS
depends:
    base-4.9.0.0 base-orphans-0.5.4-5IQvrjd7gNP548VkOOyIq6
    bifunctors-5.4.1-Ac6G6TmMVPE36jXOz0jDKq
    comonad-5-IFpew4VeZSgJKPLIcHpKjC
    contravariant-1.4-KgMYVwXYQBGKuyyJtYdP11
    distributive-0.5.2-SlRGCHnocy81GrFzDcKVs
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-profunctors/html/profunctors.haddock
haddock-html: /usr/share/doc/haskell-profunctors/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
